@@ -750,7 +750,7 @@ class Git(object):
         git_dir = self._gitDir(rpath)
         git_show = self.process(self._git, "--git-dir", git_dir, "log",
                                 "-n1", "--format=format:%H",
-                                "--quiet", reference, stderr=STDOUT)
+                                "--quiet", reference)
         if git_show.success():
             return git_show.read().strip()
         else:
